# pybind

Python bindings to `distribute` for automated creation of configuration files

## Documentation

Python documentation is available 
[here](https://fluid-dynamics-group.github.io/distribute/python/).
Python installation instructions are available [here](https://fluid-dynamics-group.github.io/distribute/install.html#python-api-install).

## Developer Documentation

Information on setting up a python developer environment with `maturin` is available in the 
crate-level documentation:

```
cargo doc --open
```

Most users will find it easiest to install from PyPi with the instructions above.
